function [ G, grad_g ] = gfun_ex5(lsf,x,grad_flag,probdata,analysisopt,gfundata,femodel,randomfield)

global nfun

nrv = size(x,1);
nx  = size(x,2);
if nx > 1, fprintf(1,'Error. Set analysisopt.multi_proc to zero.'), end

% probdata.marg = [
% 2      30       9
% 2      20       8
% 2      16     6.4
% 1  454000   40000
% 1  497000   40000
% 1    0.94    0.12
% 1    1.33    0.15
% 1    2.47    0.30
% 1    3.00    0.35
% 1    1.25    0.30
% 1    1.63    0.40
% 1    2.69    0.65
% 1    3.00    0.75
% 1    3.36    0.60
% 1    4.00    0.80
% 1    5.44    1.00
% 1    6.00    1.20
% 1    2.72    1.00
% 1    3.13    1.10
% 1    4.01    1.30
% 1    4.50    1.50 ];
% 
% x = probdata.marg(:,2);

% 2D finite element beam structure - JM Bourinet 31/01/2015

% node     :  [  node_nb  x  y ]  
node    = [  1    0    0 ;
             2   25    0 ;
             3   55    0 ;
             4   80    0 ;
            11    0   16 ;
            12   25   16 ;
            13   55   16 ;
            14   80   16 ;
            21    0   28 ;
            22   25   28 ;
            23   55   28 ;
            24   80   28 ;
            31    0   40 ;
            32   25   40 ;
            33   55   40 ;
            34   80   40 ;
            41    0   52 ;
            42   25   52 ;
            43   55   52 ;
            44   80   52 ;
            51    0   64 ;
            52   25   64 ;
            53   55   64 ;
            54   80   64 ];

kl = gfundata(lsf).cg(2);
node(:,2:3) = node(:,2:3)*kl;

% beam  :  [  beam_nb  nb_of_elements  geo_index  mat_index  1st_node_nb  2nd_node_nb  ]
beam = [   1  1  7  2   1  11 ;
           2  1  8  2   2  12 ;
           3  1  8  2   3  13 ;
           4  1  7  2   4  14 ;
          11  1  6  2  11  21 ;
          12  1  7  2  12  22 ;
          13  1  7  2  13  23 ;
          14  1  6  2  14  24 ;
          21  1  6  2  21  31 ;
          22  1  7  2  22  32 ;
          23  1  7  2  23  33 ;
          24  1  6  2  24  34 ;
          31  1  5  2  31  41 ;
          32  1  6  2  32  42 ;
          33  1  6  2  33  43 ;
          34  1  5  2  34  44 ;
          41  1  5  2  41  51 ;
          42  1  6  2  42  52 ;
          43  1  6  2  43  53 ;
          44  1  5  2  44  54 ;
          15  1  3  1  11  12 ;
          16  1  4  1  12  13 ;
          17  1  3  1  13  14 ;
          25  1  2  1  21  22 ;
          26  1  3  1  22  23 ;
          27  1  2  1  23  24 ;
          35  1  2  1  31  32 ;
          36  1  3  1  32  33 ;
          37  1  2  1  33  34 ;
          45  1  1  1  41  42 ;
          46  1  2  1  42  43 ;
          47  1  1  1  43  44 ;
          55  1  1  1  51  52 ;
          56  1  2  1  52  53 ;
          57  1  1  1  53  54 ];

% geo   :  [  geo_index  A  Iz  ] (general)

geo = [ 1  x(18)  x(10) ;  % B1 - E4
        2  x(19)  x(11) ;  % B2 - E4
        3  x(20)  x(12) ;  % B3 - E4
        4  x(21)  x(13) ;  % B4 - E4
        5  x(14)   x(6) ;  % C1 - E5
        6  x(15)   x(7) ;  % C2 - E5
        7  x(16)   x(8) ;  % C3 - E5
        8  x(17)   x(9) ]; % C4 - E5

% mats   :  [  mat_index  E  ]
mat = [ 1  x(4) ;  % E4
        2  x(5) ]; % E5

% applied point loads   :  [  node_nb  FX  FY  MZ  ]
f = [ 11   x(3)   0   0 ;  % P3
      21   x(2)   0   0 ;  % P2
      31   x(1)   0   0 ;  % P1
      41   x(1)   0   0 ;  % P1
      51   x(1)   0   0 ]; % P1

% zero displacement boundary conditions   :  [  node_nb  uX  uY  thetaZ  ]
% 1: zero displacement/rotation,  0: no constraint 
ufix = [ 1   1   1   1 ;
         2   1   1   1 ;
         3   1   1   1 ;
         4   1   1   1 ];

dim       = 2; % dimension of the problem
ndofpernd = 3; % number of dof per node

% number of beams
nb = size(beam,1);
% number of elements
ne = sum(beam(:,2));
% number of nodes
nn = length(unique(beam(:,5:6))) + sum(beam(:,2)-1);
% number of dof
ndof = ndofpernd*nn;

% preprocessing
BEAM   = zeros(ne,size(beam,2));
numnodeini = unique(beam(:,5:6));
NODE   = zeros(nn,3);
Inode  = zeros(size(node,1),1);
ne = 0;
nn = 0;
for ib = 1:nb
   
   neib = beam(ib,2);
   n1ib = beam(ib,5);
   n2ib = beam(ib,6);

   BEAM((ne+1):(ne+neib),:) = repmat(beam(ib,:),beam(ib,2),1);

   ifirst = n1ib == numnodeini;
   if any( ifirst )
      NODE(nn+1,1) = nn+1;
      NODE(nn+1,2:3) = node( n1ib==node(:,1) , 2:3);
      numnodeini( ifirst ) = nan;
      BEAM(ne+1,5) = nn+1;
      Inode( n1ib==node(:,1) ) = nn+1;
      nn = nn+1;
   else
      BEAM(ne+1,5) = Inode( n1ib==node(:,1) );
   end

   if beam(ib,2) > 1
      NODE((nn+1):(nn+neib-1),1) = ((nn+1):(nn+neib-1))';
      node1 = node( n1ib==node(:,1) , :);
      node2 = node( n2ib==node(:,1) , :);
      nodetmp = [ linspace(node1(2),node2(2),neib+1);
                  linspace(node1(3),node2(3),neib+1);
                  linspace(node1(4),node2(4),neib+1) ]';
      NODE((nn+1):(nn+neib-1),2:3) = nodetmp(2:neib,:);
      BEAM((ne+2):(ne+neib),5) = ((nn+1):(nn+neib-1))';
      BEAM((ne+1):(ne+neib-1),6) = ((nn+1):(nn+neib-1))';
      nn = nn+(neib-1);
   end
   
   ilast  = n2ib == numnodeini;
   if any( ilast )
      NODE(nn+1,1) = nn+1;
      NODE(nn+1,2:3) = node( n2ib==node(:,1) , 2:3);
      numnodeini( ilast ) = nan;
      BEAM(ne+neib,6) = nn+1;
      Inode( n2ib==node(:,1) ) = nn+1;
      nn = nn+1;
   else
      BEAM(ne+neib,6) = Inode( n2ib==node(:,1) );
   end

%    BEAM((ne+1):(ne+neib),7) = ib;
   
   ne = ne + neib;
      
end
BEAM(:,2) = 1;

% BEAM, NODE, Inode, ne, nn, return


% assembly of the stiffness matrix
K = zeros(ndof,ndof);
for ie = 1:ne
  
  conn = BEAM(ie,:);
  
  % compute element stiffness matrix
  x1 = NODE(conn(5),2); x2 = NODE(conn(6),2);
  y1 = NODE(conn(5),3); y2 = NODE(conn(6),3);
  
  CC = [ x2-x1;
         y2-y1 ];

  L = norm(CC); Le(ie) = L;
        
  c  = (x2-x1)/Le(ie);
  s  = (y2-y1)/Le(ie);
  R = [ c s 0; -s c 0; 0 0 1 ];
  
  E  = mat(BEAM(ie,4),2);
  A  = geo(BEAM(ie,3),2);
  Iz = geo(BEAM(ie,3),3);

  kexy = zeros(2*ndofpernd);
  kexy([1 ndofpernd+1],[1 ndofpernd+1]) =  E*A/L * [ 1 -1; -1 1 ];
  kexy([2 3 ndofpernd+2 ndofpernd+3],[2 3 ndofpernd+2 ndofpernd+3]) = E/L * [  12*Iz/L^2   6*Iz/L  -12*Iz/L^2   6*Iz/L ;
                                                                                   6*Iz/L     4*Iz     -6*Iz/L     2*Iz ;
                                                                               -12*Iz/L^2  -6*Iz/L   12*Iz/L^2  -6*Iz/L ;
                                                                                   6*Iz/L     2*Iz     -6*Iz/L     4*Iz ];
  keXY = [ R zeros(ndofpernd); zeros(ndofpernd) R ]' * kexy * [ R zeros(ndofpernd); zeros(ndofpernd) R ];
           
  % scatter keXY within K
  sctr = [ ndofpernd*conn(5)-2
           ndofpernd*conn(5)-1
           ndofpernd*conn(5)
           ndofpernd*conn(6)-2
           ndofpernd*conn(6)-1
           ndofpernd*conn(6) ]; % scatter vector
  K(sctr,sctr) = K(sctr,sctr) + keXY;
  
end

% applied point load vector
F = zeros(ndof,1);
for iF = 1:size(f,1)
   nodeF = Inode(f(iF,1)==node(:,1));
   F( ((nodeF-1)*ndofpernd+1):(nodeF*ndofpernd) , 1 ) = f(iF,2:4)';
end

% zero displacement boundary conditions
ifix = zeros(ndof,1);
for iu = 1:size(ufix,1)
   nodeufix = Inode(ufix(iu,1));
   ifix( ((nodeufix-1)*ndofpernd+1):(nodeufix*ndofpernd) , 1 ) = ufix(iu,2:4)';
end
ifix = find(ifix);

K(ifix,:) = 0;  % zero out rows
K(:,ifix) = 0;  % zero out cols
K(ifix,ifix) = eye(length(ifix),length(ifix)); % put ones on the diagonal
F(ifix) = 0;

% solve
U = K\F;

G = gfundata(lsf).cg(1) - U(20*3+1);

grad_g = 0;

nfun = nfun + nx;

flag_plot = 0;

if flag_plot
   
   % plot results
   def_scale = 20;
   
   % display all elements directly
   figure(1)
   clf()
   hold on
   title('Deformed plot of 3D beam problem')
   xs = reshape(NODE(BEAM(:,5:6)',2),2,ne);
   ys = reshape(NODE(BEAM(:,5:6)',3),2,ne);
   whos U
   uu  = reshape(U,3,nn);
   uu  = uu(1:2,:)';
   ux = reshape(uu(BEAM(:,5:6)',1),2,ne);
   uy = reshape(uu(BEAM(:,5:6)',2),2,ne);
   plot(xs,ys,'ks:')  % undeformed elements
   hb = plot(xs+def_scale*ux,ys+def_scale*uy,'rs-'); % plot deformed elements
   view(0,90)
   axis equal
   for in = 1:size(node,1)
      text(node(in,2),node(in,3),num2str(node(in,1)))
   end
   
end
